from java.lang import Object

class Aggregate:
    def getDesc(self) -> None: ...
    def getId(self) -> None: ...
    def getName(self) -> None: ...

class AggregateInfo(Object, Aggregate):
    def getDesc(self) -> None: ...
    def getId(self) -> None: ...
    def getName(self) -> None: ...
