from com.palantir.ptoss.cinch.core import DefaultBindableModel

class ScheduleModel(DefaultBindableModel):
    def deselectDayOfWeek(self, day) -> None: ...
    def getEveryHour(self) -> None: ...
    def getHour(self) -> None: ...
    def getMinute(self) -> None: ...
    def getSelectedDays(self) -> None: ...
    def isAlldays(self) -> None: ...
    def isDaySelected(self, day) -> None: ...
    def isEveryHourEnabled(self) -> None: ...
    def isEveryMinuteEnabled(self) -> None: ...
    def isHourEnabled(self) -> None: ...
    def isMinuteEnabled(self) -> None: ...
    def selectDayOfWeek(self, day) -> None: ...
    def setAllDays(self, allDays) -> None: ...
    def setEveryHour(self, everyHour) -> None: ...
    def setHour(self, hour) -> None: ...
    def setHourEnabled(self, hourEnabled) -> None: ...
    def setMinute(self, minute) -> None: ...
    def setMinuteEnabled(self, minuteEnabled) -> None: ...
    def setSelectedDays(self, selectedDays) -> None: ...
    def toCronString(self) -> None: ...
