from typing import List

from com.inductiveautomation.ignition.common.user import User as User
from com.palantir.ptoss.cinch.core import DefaultBindableModel as DefaultBindableModel
from java.lang import String as String

class RosterModel(DefaultBindableModel):
    def getName(self) -> String: ...
    def getUsers(self) -> List[String]: ...
    def set(self, that: RosterModel) -> None: ...
    def setName(self, name: String) -> None: ...
    def setUsers(self, users: List[User]) -> None: ...
