from typing import List

from com.inductiveautomation.ignition.common import BasicDataset
from java.lang import String

def getAccounts() -> List[String]: ...
def getAccountsDataset() -> BasicDataset: ...
def getPhoneNumbers(accountName: String) -> List[String]: ...
def getPhoneNumbersDataset(accountName: String) -> BasicDataset: ...
def sendSms(
    accountName: String, fromNumber: String, toNumber: String, message: String
) -> None: ...
