from java.lang import Object

class JythonHttpClient(Object):
    def delete(self, *args, **kwargs) -> None: ...
    def deleteAsync(self, *args, **kwargs) -> None: ...
    def get(self, *args, **kwargs) -> None: ...
    def getAsync(self, *args, **kwargs) -> None: ...
    def getConnectTimeout(self) -> None: ...
    def getCookieManager(self) -> None: ...
    def getJavaClient(self) -> None: ...
    def getRedirectPolicy(self) -> None: ...
    def head(self, *args, **kwargs) -> None: ...
    def headAsync(self, *args, **kwargs) -> None: ...
    def options(self, *args, **kwargs) -> None: ...
    def parseChart(self, contentType) -> None: ...
    def patch(self, *args, **kwargs) -> None: ...
    def patchAsync(self, *args, **kwargs) -> None: ...
    def post(self, *args, **kwargs) -> None: ...
    def postAsync(self, *args, **kwargs) -> None: ...
    def put(self, *args, **kwargs) -> None: ...
    def putAsync(self, *args, **kwargs) -> None: ...
    def request(self, *args, **kwargs) -> None: ...
    def requestAsync(self, *args, **kwargs) -> None: ...
    def setGson(self, gson) -> None: ...
    def trace(self, *args, **kwargs) -> None: ...
    def traceAsync(self, *args, **kwargs) -> None: ...
