class ClientContext:
    def addPropertyChangeListener(self, *args) -> None: ...
    def desearilize(self, data, log) -> None: ...
    def getAuthProfileName(self) -> None: ...
    def getDefaultDataSourceName(self) -> None: ...
    def getDefaultTagProviderName(self) -> None: ...
    def getExecutionManager(self) -> None: ...
    def getLaunchContext(self) -> None: ...
    def getLocalizationManager(self) -> None: ...
    def getModules(self) -> None: ...
    def getNamedQueryManager(self) -> None: ...
    def getProgressManager(self) -> None: ...
    def getProject(self) -> None: ...
    def getProjectName(self) -> None: ...
    def getRootPaneContainer(self) -> None: ...
    def getTagManager(self) -> None: ...
    def getTagPollRate(self) -> None: ...
    def getUIEventBus(self) -> None: ...
    def removePropertyChangeListened(self, *args) -> None: ...
