from java.lang import Object

class Annotation(Object):
    def delete(self) -> None: ...
    @staticmethod
    def fromJson(json) -> None: ...
    def getData(self) -> None: ...
    def getPath(self) -> None: ...
    def getRangeEnd(self) -> None: ...
    def getRangeStart(self) -> None: ...
    def getStorageId(self) -> None: ...
    def getType(self) -> None: ...
    def isDeleted(self) -> None: ...
    @staticmethod
    def newBuilder() -> None: ...
    @staticmethod
    def newDelete(storageId) -> None: ...
    def toJson(self) -> None: ...
    def updatePath(self, path) -> None: ...
