from typing import Any

class AlarmQueryResult:
    def getAssociatedDate(self, uuid) -> None: ...
    def getDataSet(self) -> None: ...
    def getEvent(self, uuid) -> None: ...

class AlarmQueryResultImpl(AlarmQueryResult):
    def __init__(self, *args: Any) -> None: ...
    def __iter__(self): ...
    def getAssociatedDate(self, uuid) -> None: ...
    def getDataSet(self) -> None: ...
    def getEvent(self, uuid) -> None: ...
