from java.lang import Object

class PyChartScope(Object):
    def __set__(self, instance, value) -> None: ...
    def __setattr__(self, key, value) -> None: ...
    def __setitem__(self, key, value) -> None: ...
