from typing import Optional, Tuple

from java.lang import String
from java.util import EventObject

def getRoles() -> Tuple[String, ...]: ...
def getUserRoles(
    username: String, password: String, authProfile: String = ..., timeout: int = ...
) -> Optional[Tuple[String, ...]]: ...
def getUsername() -> String: ...
def isScreenLocked() -> bool: ...
def lockScreen(obscure: Optional[bool] = ...) -> None: ...
def logout() -> None: ...
def switchUser(
    username: String,
    password: String,
    event: EventObject,
    hideError: Optional[bool] = ...,
) -> bool: ...
def unlockScreen() -> None: ...
def validateUser(
    username: String,
    password: String,
    authProfile: Optional[String] = ...,
    timeout: Optional[int] = ...,
) -> bool: ...
