from typing import Any, Dict, Optional

from com.inductiveautomation.ignition.common import BasicDataset
from com.inductiveautomation.sfc.api import PyChartScope
from java.lang import String

def cancelChart(instanceId: String) -> None: ...
def getRunningCharts(chartPath: Optional[String] = ...) -> BasicDataset: ...
def getVariables(instanceId: String) -> PyChartScope: ...
def pauseChart(instanceId: String) -> None: ...
def redundantCheckpoint(instanceId: String) -> None: ...
def resumeChart(instanceId: String) -> None: ...
def setVariable(
    instanceId: String, stepId: String, variableName: String, variableValue: Any
) -> None: ...
def setVariables(
    instanceId: String, stepId: String, variableMap: Dict[String, Any]
) -> None: ...
def startChart(
    projectName: String, chartPath: String, arguments: Dict[String, Any]
) -> String: ...
